// Package water is a simple TUN/TAP interface library that efficiently works
// with standard packages like io, bufio, etc.. Use waterutil with it to work
// with TUN/TAP packets/frames.
package water
